MechFsmState

Enum MechFsmState 

#[repr(i16)]
pub enum MechFsmState { Invalid = 0, StartUp = 1, Init = 5, Idle = 10, Executing = 20, CmdDone = 100, Error = 900, }
A list of status codes for returned by a remote or external state machine intended to receive and execute commands.

Variants



Invalid = 0

Invalid. The Status of the FSM should never be 0. This just means communications hasn’t updated the value.



StartUp = 1

The state machine is in its StartUp state. The FSM will automatically enter this state when it starts running.

In this state, the state machine handles its internal business and, if successful, increments to the Init state. This is a good state for the FSM to establish/re-establish any communications. This state is not intended to be part of the normally-executing process.



Init = 5

The state machine is in the Init state. This is the state before Idle where any values are reset; it is the entrance point to the process of the state machine. The FSM will go to this state after an error, and can be sent here by request from the FSM client, usually to stop a command in process.



Idle = 10

The state machine is Idle. It ready to accept and execute commands.



Executing = 20

The state machine is executing a command, read or write request. Theoretically, an Init control code would stop execution of the command and reset the state machine, although that is not always practical.



CmdDone = 100

The state machine has completed the command, read or write request. It will wait for an AckDone before returning to Idle, or an Init to reset.



Error = 900

The state machine has encountered an error. It will wait for an AckDone before returning to Idle, or an Init to reset.