pub struct ModuleRegistration {
pub name: String,
pub version: String,
pub capabilities: Vec<String>,
}Expand description
Registration message sent by module when connecting to server.
This is sent as the data payload of a Control message with ControlType::Register.
Fields
name: StringUnique name/identifier for this module (becomes its domain)
version: StringModule version string
capabilities: Vec<String>List of topics/capabilities this module provides
Implementations
Sourceimpl ModuleRegistration
impl ModuleRegistration
pub fn new(name: &str, version: &str) -> Self
pub fn with_capabilities(self, caps: Vec<String>) -> Self
Sourcepub fn to_command_message(&self) -> CommandMessage
pub fn to_command_message(&self) -> CommandMessage
Convert to a CommandMessage for sending over IPC
Sourcepub fn from_command_message(msg: &CommandMessage) -> Result<Self, Error>
pub fn from_command_message(msg: &CommandMessage) -> Result<Self, Error>
Parse from a CommandMessage’s data field