pub struct MechFsmStatusTuple {
pub transaction_id: u32,
pub state: MechFsmState,
pub crc: u32,
pub data: MechFsmCommandArgTuple,
}Expand description
Represents the status response from a state machine in a remote server or device.
Fields
transaction_id: u32Transaction ID. Should be non-zero. The transaction ID should match the ID from the command.
state: MechFsmStateStatus code. Represents a state of execution of the state machine in the remote server or device.
crc: u32Cyclical Redundancy Checksum. 32-bit. Optional. Don’t set manually. Unless a custom CRC value is required, use the calculate_crc32 function.
data: MechFsmCommandArgTupleArguments and data values that can be sent along with the command, designed to be compatible with fixed-memory industrial controllers. The command arg tuple can contain up to 255 columns arguments, depending upon the size of the individual arguments. In that way, a command can be executed in less time because there needs be only one transmission: the command code and its arguments all in one package.
Implementations